Module: XBMC

Defined in:
lib/ruby-xbmc.rb

Overview

Module for the library

=Usage example First, we need to create the link between us and XBMC:

xbmc = XBMC::XBMC.new(hostname, port, user, pass)

then, we can do a lot of things, following XBMC API.

==Set current XBMC Volume xbmc.SetVolume(95) ==Get currently playing file data xbmc.GetCurrentlyPlaying ==Get a files list from music library, with insertion dates xbmc.GetMediaLocation("music", "/mnt/data/Music/Jazz/", true) ==Retrieve playlist contents xbmc.GetPlaylistContents ==Get some system information xbmc.GetSystemInfoByName("weather.location","weather.temperature")

Defined Under Namespace

Classes: Connection, UnauthenticatedError, WrongCredentialsError, XBMC

Constant Summary collapse

NAME =

User Agent Name

'Ruby/XBMC'
VERSION =

Library Version

'0.1'
USER_AGENT =

Complete User-Agent

"%s %s" % [NAME, VERSION]
SCHEME =

scheme used in HTTP transfers (http/https)

"http"
CMDPATH =

XBMC Command API

"/xbmcCmds/xbmcHttp?command="
MUSIC_PLAYLIST =
0
VIDEO_PLAYLIST =
1
TYPE_DIRECTORY =
1
TYPE_FILE =
0